==> hpmgmt-7.2.0-vmware.tgz: opt/hp/support/cs-final.sh <==
#!/bin/sh
#
CS_ROOT=/opt/hp
CS_WORK=/opt/hp/hpsmh
CS_HELP=/opt/hp/hpsmh/data/help
CS_SUPP=/opt/hp/support
#
#
#
## Create 'hpsmh' User and Group
#
#/usr/sbin/groupadd -g 79 hpsmh
#/usr/sbin/useradd -u 79 -g 79 -s /sbin/nologin -M -r -d $CS_ROOT/hpsmh hpsmh
#
## Create logs under /var/spool
#
if [ ! -d /var/spool/opt ]; then
  mkdir /var/spool/opt
  mkdir /var/spool/opt/hp
  mkdir /var/spool/opt/hp/hpsmh
  mkdir /var/spool/opt/hp/hpsmh/logs
  mkdir /var/spool/opt/hp/hpsmh/run
  chown -R root:hpsmh /var/spool/opt
  chmod -R 750 /var/spool/opt
fi
## Move in PHP configuration
# This in the spec file now
#mkdir $CS_WORK/php
#mkdir $CS_WORK/php/lib
#cp -v $CS_SUPP/php.ini $CS_WORK/php/lib
#
## Move in the redirect page(s) (Now done before! - JKP)
#
#mv $CS_WORK/data/htdocs/red2301.html.en $CS_WORK/data/isdocs/red2301.html.en
#
#
INITREE=/opt/hp/hpsmh
fn=/tmp/files.tmp
rm -f "$fn"
/usr/bin/find "$INITREE" -name '*' -print >> "$fn"
# Did we find any files?
l_c=$(/usr/bin/wc -l $fn | awk '{print $1}')
if [[ $l_c != 0 ]]; then
   for rl in $(seq 0 $l_c)
   do
     read rline;
     thefile=${rline:0}
     if [ -d $thefile ]; then
        chmod 750 $thefile > /dev/null 2>&1
        chown 79:79 $thefile > /dev/null 2>&1
     fi
   done <$fn
fi
rm -f /tmp/files.tmp
chmod 750 /opt/hp > /dev/null 2>&1
chown 79:79 /opt/hp > /dev/null 2>&1
chmod 750 /opt/hp/sslshare > /dev/null 2>&1
chown 79:79 /opt/hp/sslshare > /dev/null 2>&1
#
chown root:hpsmh $CS_WORK/sbin/cgi_pam
chmod 4755 $CS_WORK/sbin/cgi_pam
chown root:hpsmh $CS_WORK/sbin/smhstart
chmod 4755 $CS_WORK/sbin/smhstart
#
## Set file permissions 
#
chmod 755  /opt/hp/support/hpsmhd*
chmod 644  /opt/hp/support/sysmgthp.*
chmod 644  /opt/hp/hpsmh/certs/* > /dev/null 2>&1
# Namazu
chmod 640  /opt/hp/hpsmh/namazu/template/*
chmod 755 /opt/hp/hpsmh/namazu/template
#
#
chmod 640  /opt/hp/hpsmh/conf/mime.types
chmod 640  /opt/hp/hpsmh/conf/magic
chmod 750  /opt/hp/hpsmh/sbin/*
#chmod 640  /opt/hp/hpsmh/sbin/envvars-std
#chmod 640  /opt/hp/hpsmh/sbin/envvars
#chmod 4750  /opt/hp/hpsmh/sbin/suexec
chmod 4750  /opt/hp/hpsmh/sbin/cgi_pam
chmod 4750  /opt/hp/hpsmh/sbin/smhstart
chmod 750  /opt/hp/hpsmh/modules/*
chmod 640  /opt/hp/hpsmh/modules/httpd.exp
chmod 750  /opt/hp/hpsmh/modules/mod_smh_help.so
chmod 750  /opt/hp/hpsmh/modules/libphp4.so
#chmod 750  /opt/hp/hpsmh/bin/apr-config
#chmod 750  /opt/hp/hpsmh/bin/apu-config
chmod 750  /opt/hp/hpsmh/data/help/WEB_INF/cgi/namazu.cgi
chmod 640  /opt/hp/hpsmh/data/help/WEB_INF/cgi/.namazurc
#
chmod 750  /opt/hp/hpsmh/data/help/*.jar
chmod 750  /opt/hp/hpsmh/data/help/*.res
chmod 750  /opt/hp/hpsmh/data/help/*.js
chmod 640  /opt/hp/hpsmh/data/help/*.htm
chmod 640  /opt/hp/hpsmh/data/help/*.css
chmod 640  /opt/hp/hpsmh/data/help/graphics/*.png
chmod 640 /opt/hp/hpsmh/data/help/proxy/en/*.html
chmod 640 /opt/hp/hpsmh/data/help/proxy/en/*.xml
chmod 640 /opt/hp/hpsmh/data/help/proxy/en/sys-map.properties
chmod 640 /opt/hp/hpsmh/data/help/WEB_INF/cgi/var/en/proxy/*
#
chmod 750  /opt/hp/hpsmh/data/isdocs/red2301.html.en
# Ginkgo Add-in
#chmod 640  /opt/hp/hpsmh/data/smhutil/*
#
chmod 640  /opt/hp/hpsmh/data/htdocs/*.js
chmod 640  /opt/hp/hpsmh/data/htdocs/*.gif
chmod 640  /opt/hp/hpsmh/data/htdocs/*.jpg
chmod 640  /opt/hp/hpsmh/data/htdocs/*.en
chmod 640  /opt/hp/hpsmh/data/htdocs/*.htm
chmod 750  /opt/hp/hpsmh/lib/libapr-0.so.0.9.?
chmod 770  /opt/hp/hpsmh/lib/libapr-0.so.0
chmod 770  /opt/hp/hpsmh/lib/libapr-0.so
chmod 640  /opt/hp/hpsmh/lib/libapr-0.la
#chmod 640  /opt/hp/hpsmh/lib/libapr-0.a
chmod 640  /opt/hp/hpsmh/lib/apr.exp
chmod 750  /opt/hp/hpsmh/lib/libaprutil-0.so.0.9.?
chmod 770  /opt/hp/hpsmh/lib/libaprutil-0.so.0
chmod 770  /opt/hp/hpsmh/lib/libaprutil-0.so
chmod 640  /opt/hp/hpsmh/lib/libaprutil-0.la
#chmod 640  /opt/hp/hpsmh/lib/libaprutil-0.a
chmod 640  /opt/hp/hpsmh/lib/aprutil.exp
#
#
chmod 770  /opt/hp/hpsmh/lib/libxml2.so
#chmod 770  /opt/hp/hpsmh/lib/libxslt.so
#chmod 770  /opt/hp/hpsmh/lib/libexslt.so
#
chmod 770  /opt/hp/hpsmh/lib/libxml2.so.2
#chmod 770  /opt/hp/hpsmh/lib/libxslt.so.1
#chmod 770  /opt/hp/hpsmh/lib/libexslt.so.0
#
chmod 750  /opt/hp/hpsmh/lib/libxml2.so.2.6.8
#chmod 750  /opt/hp/hpsmh/lib/libxslt.so.1.1.4
#chmod 750  /opt/hp/hpsmh/lib/libexslt.so.0.8.4
#
#chmod 750  /opt/hp/hpsmh/lib/libxml2.a
#chmod 750  /opt/hp/hpsmh/lib/libxslt.a
#chmod 750  /opt/hp/hpsmh/lib/libexslt.a
#
chmod 750  /opt/hp/hpsmh/lib/libxml2.la
#chmod 750  /opt/hp/hpsmh/lib/libxslt.la
#chmod 750  /opt/hp/hpsmh/lib/libexslt.la
#
#
#chmod 640  /opt/hp/hpsmh/include/*
#
## Determine Linux Distribution and fixup accordingly 
#
if [[ -f /etc/redhat-release || -x /usr/bin/vmware ]]; then
  #
  ## Add in the startup script & PAM stack (RedHat)
  #
  cp -f $CS_SUPP/sysmgthp.redhat /etc/pam.d/sysmgthp
  cp -f $CS_SUPP/hpsmhd.redhat /etc/init.d/hpsmhd
  cp -f $CS_SUPP/fixperms /etc/init.d/fixperms

  chmod 644 /etc/pam.d/sysmgthp
  chmod 755 /etc/init.d/hpsmhd
  chmod 755 /etc/init.d/fixperms
  chkconfig --add hpsmhd
  chkconfig --level 345 hpsmhd on
fi
if [[ -f /etc/UnitedLinux-release || -f /etc/SuSE-release ]]; then
  #
  ## Add in the startup scripts, symlinks, & PAM stack (United/SuSE8)
  #
#  if [ -f /usr/lib/libssl.so ]; then
#    ln -s /usr/lib/libssl.so /lib/libssl.so.2 >> /dev/null 2>&1
#    ln -s /usr/lib/libcrypto.so /lib/libcrypto.so.2 >> /dev/null 2>&1
#  fi
#  if [ -f /usr/lib/libssl.so.0 ]; then
#    ln -s /usr/lib/libssl.so.0 /usr/lib/libssl.so >> /dev/null 2>&1
#    ln -s /usr/lib/libcrypto.so.0 /usr/lib/libcrypto.so >> /dev/null 2>&1
#    ln -s /usr/lib/libssl.so /lib/libssl.so.2 >> /dev/null 2>&1
#    ln -s /usr/lib/libcrypto.so /lib/libcrypto.so.2 >> /dev/null 2>&1
#  fi
 cp -f $CS_SUPP/sysmgthp.united1 /etc/pam.d/sysmgthp
 cp -f $CS_SUPP/hpsmhd.united1 /etc/init.d/hpsmhd
 cp -f $CS_SUPP/fixperms /etc/init.d/fixperms
 chmod 644 /etc/pam.d/sysmgthp
 chmod 755 /etc/init.d/hpsmhd
 chmod 755 /etc/init.d/fixperms
 chkconfig --add hpsmhd
fi
#
## Remove Support Directory
#
rm -rf /opt/hp/support

==> hpmgmt-7.4.0b-vmware.tgz: opt/hp/support/cs-final.sh <==
#!/bin/sh
#
CS_ROOT=/opt/hp
CS_WORK=/opt/hp/hpsmh
CS_HELP=/opt/hp/hpsmh/data/help
CS_SUPP=/opt/hp/support
#
#
#
## Create 'hpsmh' User and Group
#
#/usr/sbin/groupadd -g 79 hpsmh
#/usr/sbin/useradd -u 79 -g 79 -s /sbin/nologin -M -r -d $CS_ROOT/hpsmh hpsmh
#
## Create logs under /var/spool
#
if [ ! -d /var/spool/opt ]; then
  mkdir /var/spool/opt
  mkdir /var/spool/opt/hp
  mkdir /var/spool/opt/hp/hpsmh
  mkdir /var/spool/opt/hp/hpsmh/logs
  mkdir /var/spool/opt/hp/hpsmh/run
  chown -R root:hpsmh /var/spool/opt
  chmod -R 750 /var/spool/opt
fi
## Move in PHP configuration
# This in the spec file now
#mkdir $CS_WORK/php
#mkdir $CS_WORK/php/lib
#cp -v $CS_SUPP/php.ini $CS_WORK/php/lib
#
## Move in the redirect page(s) (Now done before! - JKP)
#
#mv $CS_WORK/data/htdocs/red2301.html.en $CS_WORK/data/isdocs/red2301.html.en
#
#
INITREE=/opt/hp/hpsmh
fn=/tmp/files.tmp
rm -f "$fn"
/usr/bin/find "$INITREE" -name '*' -print >> "$fn"
# Did we find any files?
l_c=$(/usr/bin/wc -l $fn | awk '{print $1}')
if [[ $l_c != 0 ]]; then
   for rl in $(seq 0 $l_c)
   do
     read rline;
     thefile=${rline:0}
     if [ -d $thefile ]; then
        chmod 750 $thefile > /dev/null 2>&1
        chown 79:79 $thefile > /dev/null 2>&1
     fi
   done <$fn
fi
rm -f /tmp/files.tmp
chmod 750 /opt/hp > /dev/null 2>&1
chown 79:79 /opt/hp > /dev/null 2>&1
chmod 750 /opt/hp/sslshare > /dev/null 2>&1
chown 79:79 /opt/hp/sslshare > /dev/null 2>&1
#
chown root:hpsmh $CS_WORK/sbin/cgi_pam
chmod 4755 $CS_WORK/sbin/cgi_pam
chown root:hpsmh $CS_WORK/sbin/smhstart
chmod 4755 $CS_WORK/sbin/smhstart
#
## Set file permissions 
#
chmod 755  /opt/hp/support/hpsmhd*
chmod 644  /opt/hp/support/sysmgthp.*
chmod 644  /opt/hp/hpsmh/certs/* > /dev/null 2>&1
# Namazu
chmod 640  /opt/hp/hpsmh/namazu/template/*
chmod 755 /opt/hp/hpsmh/namazu/template
#
#
chmod 640  /opt/hp/hpsmh/conf/mime.types
chmod 640  /opt/hp/hpsmh/conf/magic
chmod 750  /opt/hp/hpsmh/sbin/*
#chmod 640  /opt/hp/hpsmh/sbin/envvars-std
#chmod 640  /opt/hp/hpsmh/sbin/envvars
#chmod 4750  /opt/hp/hpsmh/sbin/suexec
chmod 4750  /opt/hp/hpsmh/sbin/cgi_pam
chmod 4750  /opt/hp/hpsmh/sbin/smhstart
chmod 750  /opt/hp/hpsmh/modules/*
chmod 640  /opt/hp/hpsmh/modules/httpd.exp
chmod 750  /opt/hp/hpsmh/modules/mod_smh_help.so
chmod 750  /opt/hp/hpsmh/modules/libphp4.so
#chmod 750  /opt/hp/hpsmh/bin/apr-config
#chmod 750  /opt/hp/hpsmh/bin/apu-config
chmod 750  /opt/hp/hpsmh/data/help/WEB_INF/cgi/namazu.cgi
chmod 640  /opt/hp/hpsmh/data/help/WEB_INF/cgi/.namazurc
#
chmod 750  /opt/hp/hpsmh/data/help/*.jar
chmod 750  /opt/hp/hpsmh/data/help/*.res
chmod 750  /opt/hp/hpsmh/data/help/*.js
chmod 640  /opt/hp/hpsmh/data/help/*.htm
chmod 640  /opt/hp/hpsmh/data/help/*.css
chmod 640  /opt/hp/hpsmh/data/help/graphics/*.png
chmod 640 /opt/hp/hpsmh/data/help/proxy/en/*.html
chmod 640 /opt/hp/hpsmh/data/help/proxy/en/*.xml
chmod 640 /opt/hp/hpsmh/data/help/proxy/en/sys-map.properties
chmod 640 /opt/hp/hpsmh/data/help/WEB_INF/cgi/var/en/proxy/*
#
chmod 750  /opt/hp/hpsmh/data/isdocs/red2301.html.en
# Ginkgo Add-in
#chmod 640  /opt/hp/hpsmh/data/smhutil/*
#
chmod 640  /opt/hp/hpsmh/data/htdocs/*.js
chmod 640  /opt/hp/hpsmh/data/htdocs/*.gif
chmod 640  /opt/hp/hpsmh/data/htdocs/*.jpg
chmod 640  /opt/hp/hpsmh/data/htdocs/*.en
chmod 640  /opt/hp/hpsmh/data/htdocs/*.htm
chmod 750  /opt/hp/hpsmh/lib/libapr-0.so.0.9.?
chmod 770  /opt/hp/hpsmh/lib/libapr-0.so.0
chmod 770  /opt/hp/hpsmh/lib/libapr-0.so
chmod 640  /opt/hp/hpsmh/lib/libapr-0.la
#chmod 640  /opt/hp/hpsmh/lib/libapr-0.a
chmod 640  /opt/hp/hpsmh/lib/apr.exp
chmod 750  /opt/hp/hpsmh/lib/libaprutil-0.so.0.9.?
chmod 770  /opt/hp/hpsmh/lib/libaprutil-0.so.0
chmod 770  /opt/hp/hpsmh/lib/libaprutil-0.so
chmod 640  /opt/hp/hpsmh/lib/libaprutil-0.la
#chmod 640  /opt/hp/hpsmh/lib/libaprutil-0.a
chmod 640  /opt/hp/hpsmh/lib/aprutil.exp
#
#
chmod 770  /opt/hp/hpsmh/lib/libxml2.so
#chmod 770  /opt/hp/hpsmh/lib/libxslt.so
#chmod 770  /opt/hp/hpsmh/lib/libexslt.so
#
chmod 770  /opt/hp/hpsmh/lib/libxml2.so.2
#chmod 770  /opt/hp/hpsmh/lib/libxslt.so.1
#chmod 770  /opt/hp/hpsmh/lib/libexslt.so.0
#
chmod 750  /opt/hp/hpsmh/lib/libxml2.so.*
#chmod 750  /opt/hp/hpsmh/lib/libxslt.so.1.1.4
#chmod 750  /opt/hp/hpsmh/lib/libexslt.so.0.8.4
#
#chmod 750  /opt/hp/hpsmh/lib/libxml2.a
#chmod 750  /opt/hp/hpsmh/lib/libxslt.a
#chmod 750  /opt/hp/hpsmh/lib/libexslt.a
#
chmod 750  /opt/hp/hpsmh/lib/libxml2.la
#chmod 750  /opt/hp/hpsmh/lib/libxslt.la
#chmod 750  /opt/hp/hpsmh/lib/libexslt.la
#
#
#chmod 640  /opt/hp/hpsmh/include/*
#
## Determine Linux Distribution and fixup accordingly 
#
if [[ -f /etc/redhat-release || -x /usr/bin/vmware ]]; then
  #
  ## Add in the startup script & PAM stack (RedHat)
  #
  cp -f $CS_SUPP/sysmgthp.redhat /etc/pam.d/sysmgthp
  cp -f $CS_SUPP/hpsmhd.redhat /etc/init.d/hpsmhd
  cp -f $CS_SUPP/fixperms /etc/init.d/fixperms

  chmod 644 /etc/pam.d/sysmgthp
  chmod 755 /etc/init.d/hpsmhd
  chmod 755 /etc/init.d/fixperms
  chkconfig --add hpsmhd
  chkconfig --level 345 hpsmhd on
fi
if [[ -f /etc/UnitedLinux-release || -f /etc/SuSE-release ]]; then
  #
  ## Add in the startup scripts, symlinks, & PAM stack (United/SuSE8)
  #
#  if [ -f /usr/lib/libssl.so ]; then
#    ln -s /usr/lib/libssl.so /lib/libssl.so.2 >> /dev/null 2>&1
#    ln -s /usr/lib/libcrypto.so /lib/libcrypto.so.2 >> /dev/null 2>&1
#  fi
#  if [ -f /usr/lib/libssl.so.0 ]; then
#    ln -s /usr/lib/libssl.so.0 /usr/lib/libssl.so >> /dev/null 2>&1
#    ln -s /usr/lib/libcrypto.so.0 /usr/lib/libcrypto.so >> /dev/null 2>&1
#    ln -s /usr/lib/libssl.so /lib/libssl.so.2 >> /dev/null 2>&1
#    ln -s /usr/lib/libcrypto.so /lib/libcrypto.so.2 >> /dev/null 2>&1
#  fi
 cp -f $CS_SUPP/sysmgthp.united1 /etc/pam.d/sysmgthp
 cp -f $CS_SUPP/hpsmhd.united1 /etc/init.d/hpsmhd
 cp -f $CS_SUPP/fixperms /etc/init.d/fixperms
 chmod 644 /etc/pam.d/sysmgthp
 chmod 755 /etc/init.d/hpsmhd
 chmod 755 /etc/init.d/fixperms
 chkconfig --add hpsmhd
fi
#
## Remove Support Directory
#
rm -rf /opt/hp/support
